@@ -382,10 +382,14 @@ on_drag_data_received (GtkWidget        *widget,
       BijiNoteBook *book;
       BijiNoteObj *ret;
       BjbMainView *self = BJB_MAIN_VIEW (user_data);
+      BjbSettings *settings;
 
       /* FIXME Text is guchar utf 8, conversion to perform */
-      book =  bjb_window_base_get_book (self->priv->window); 
-      ret = biji_note_book_note_new (book, (gchar*) text);
+      book =  bjb_window_base_get_book (self->priv->window);
+      settings = bjb_app_get_settings (g_application_get_default ());
+      ret = biji_note_book_note_new (book,
+                                     (gchar*) text,
+                                     bjb_settings_get_default_location (settings));
       switch_to_note_view (self, ret); // maybe AFTER drag finish?
 
       g_free (text);
@@ -444,13 +448,9 @@ bjb_main_view_constructed(GObject *o)
   priv->view = gd_main_view_new (DEFAULT_VIEW);
 
   /* Main view */
-  overlay = GTK_OVERLAY (gtk_overlay_new ());
-
   gd_main_view_set_selection_mode (priv->view, FALSE);
   gd_main_view_set_model (priv->view, bjb_controller_get_model(priv->controller));
-
-  gtk_container_add (GTK_CONTAINER (overlay), GTK_WIDGET (priv->view));
-  gtk_box_pack_start (vbox, GTK_WIDGET (overlay), TRUE, TRUE, 0);
+  gtk_box_pack_start (vbox, GTK_WIDGET (priv->view), TRUE, TRUE, 0);
 
   /* Load more */
   priv->load_more = bjb_load_more_button_new (priv->controller);
@@ -458,7 +458,7 @@ bjb_main_view_constructed(GObject *o)
 
   /* Selection Panel */
   priv->select_bar = bjb_selection_toolbar_new (priv->view, self);
-  gtk_overlay_add_overlay (overlay, GTK_WIDGET (priv->select_bar));
+  gtk_box_pack_start (vbox, priv->select_bar, FALSE, FALSE, 0);
 
   /* Drag n drop */
   gtk_drag_dest_set (GTK_WIDGET (priv->view), GTK_DEST_DEFAULT_ALL,
