@@ -55,7 +55,7 @@ GType biji_collection_get_type (void);
 /* Exiting coll in tracker : provide urn & iso8601 date
  * To create a brand new collection in tracker rather gobjectize existing one,
  * see biji_create_new_collection_async */
-BijiCollection * biji_collection_new (GObject *book, gchar *urn, gchar *name, gchar *mtime);
+BijiCollection * biji_collection_new (GObject *book, gchar *urn, gchar *name, gint64 mtime);
 
 
 /* Watching for tracker would be best. Right now manually called. */
